/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import BEMHelper from 'react-bem-helper';
import Button from 'ndla-button';
import { BrightcoveShape, YouTubeShape } from './shapes';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

var VideoLoadMoreButton = function VideoLoadMoreButton(props) {
  var videos = props.videos,
      searching = props.searching,
      limit = props.limit,
      translations = props.translations,
      loadMoreVideos = props.loadMoreVideos;


  if (!videos || videos.length === 0 || videos.length % limit !== 0) {
    return null;
  }
  return React.createElement(
    'div',
    classes('load-videos'),
    React.createElement(
      Button,
      { disabled: searching, onClick: loadMoreVideos },
      searching ? React.createElement('div', classes('spinner')) : translations.loadMoreVideos
    )
  );
};

VideoLoadMoreButton.propTypes = {
  searching: PropTypes.bool.isRequired,
  videos: PropTypes.oneOfType([PropTypes.arrayOf(BrightcoveShape), PropTypes.arrayOf(YouTubeShape)]),
  translations: PropTypes.shape({
    searchPlaceholder: PropTypes.string.isRequired,
    searchButtonTitle: PropTypes.string.isRequired,
    loadMoreVideos: PropTypes.string.isRequired
  }),
  limit: PropTypes.number.isRequired,
  loadMoreVideos: PropTypes.func.isRequired
};

export default VideoLoadMoreButton;