/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import BEMHelper from 'react-bem-helper';
import { BrightcoveShape, YouTubeShape } from './shapes';

import VideoSearchResultBrightcove from './VideoSearchResultBrightcove';
import VideoSearchResultYouTube from './VideoSearchResultYouTube';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

var VideoSearchList = function VideoSearchList(props) {
  var videos = props.videos,
      locale = props.locale,
      translations = props.translations,
      selectedType = props.selectedType,
      selectedVideo = props.selectedVideo,
      onSelectVideo = props.onSelectVideo,
      onVideoPreview = props.onVideoPreview,
      searching = props.searching;


  if ((!videos || videos.length === 0) && !searching) {
    return React.createElement(
      'p',
      null,
      translations.noResults
    );
  }
  if (searching && !(videos.length > 0)) {
    return React.createElement('div', classes('result-spinner'));
  }

  var videoresults = function videoresults() {
    if (selectedType === 'youtube') {
      return videos.map(function (video) {
        return React.createElement(VideoSearchResultYouTube, {
          key: video.pagemap.videoobject[0].videoid,
          video: video,
          onVideoPreview: onVideoPreview,
          selectedVideo: selectedVideo,
          onSelectVideo: onSelectVideo,
          translations: translations,
          locale: locale
        });
      });
    }

    return videos.map(function (video) {
      return React.createElement(VideoSearchResultBrightcove, {
        key: video.id,
        video: video,
        onVideoPreview: onVideoPreview,
        selectedVideo: selectedVideo,
        onSelectVideo: onSelectVideo,
        locale: locale,
        translations: translations
      });
    });
  };

  return React.createElement(
    'div',
    classes('list-inner'),
    videoresults()
  );
};

VideoSearchList.propTypes = {
  onSelectVideo: PropTypes.func.isRequired,
  onVideoPreview: PropTypes.func.isRequired,
  searching: PropTypes.bool.isRequired,
  selectedType: PropTypes.string.isRequired,
  selectedVideo: PropTypes.oneOfType([BrightcoveShape, YouTubeShape]),
  videos: PropTypes.oneOfType([PropTypes.arrayOf(BrightcoveShape), PropTypes.arrayOf(YouTubeShape)]),
  translations: PropTypes.shape({
    searchPlaceholder: PropTypes.string.isRequired,
    searchButtonTitle: PropTypes.string.isRequired,
    loadMoreVideos: PropTypes.string.isRequired
  }),
  locale: PropTypes.string.isRequired
};

export default VideoSearchList;