var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import React from 'react';
import PropTypes from 'prop-types';
import Button from 'ndla-button';
import BEMHelper from 'react-bem-helper';
import PreviewVideo from './PreviewVideo';
import { YouTubeShape } from './shapes';
import { setLocaleDate, setYouTubeDuration } from './videoHelpers';

var classes = new BEMHelper({
  name: 'video-search',
  prefix: 'c-'
});

export default function VideoSearchResultYouTube(_ref) {
  var video = _ref.video,
      onVideoPreview = _ref.onVideoPreview,
      selectedVideo = _ref.selectedVideo,
      onSelectVideo = _ref.onSelectVideo,
      translations = _ref.translations,
      locale = _ref.locale;

  var videoData = video.pagemap.videoobject[0];
  var active = selectedVideo && selectedVideo.pagemap.videoobject[0].videoid === videoData.videoid ? 'active' : '';

  return React.createElement(
    'div',
    _extends({ key: videoData.videoid }, classes('list-item', active)),
    React.createElement(
      'div',
      classes('list-item-inner'),
      React.createElement('img', {
        role: 'presentation',
        alt: 'presentation',
        src: videoData.thumbnailurl
      }),
      React.createElement(
        'div',
        classes('information'),
        React.createElement(
          'h2',
          null,
          videoData.name
        ),
        React.createElement(
          'div',
          null,
          translations.publishedDate + ': ' + setLocaleDate(videoData.datepublished, locale)
        ),
        React.createElement(
          'div',
          null,
          translations.duration + ': ' + setYouTubeDuration(videoData.duration)
        ),
        React.createElement(
          'div',
          null,
          translations.interactioncount + ': ' + videoData.interactioncount
        ),
        React.createElement(
          'div',
          null,
          videoData.description
        ),
        React.createElement(
          Button,
          _extends({}, classes('button'), {
            outline: true,
            onClick: function onClick() {
              return onVideoPreview(video);
            } }),
          translations.previewVideo
        ),
        React.createElement(
          Button,
          _extends({}, classes('button'), { onClick: function onClick() {
              return onSelectVideo(video);
            } }),
          translations.addVideo
        )
      )
    ),
    selectedVideo && selectedVideo.pagemap.videoobject[0].videoid === videoData.videoid ? React.createElement(
      PreviewVideo,
      { onVideoPreview: onVideoPreview, selectedType: 'youtube' },
      React.createElement('iframe', {
        className: 'c-video-preview__video',
        title: selectedVideo.title,
        src: selectedVideo.pagemap.videoobject[0].embedurl,
        allowFullScreen: true
      })
    ) : ''
  );
}

VideoSearchResultYouTube.propTypes = {
  video: YouTubeShape.isRequired,
  onVideoPreview: PropTypes.func.isRequired,
  selectedVideo: YouTubeShape,
  onSelectVideo: PropTypes.func.isRequired,
  locale: PropTypes.string.isRequired,
  translations: PropTypes.shape({
    addVideo: PropTypes.string.isRequired,
    previewVideo: PropTypes.string.isRequired,
    publishedDate: PropTypes.string.isRequired
  })
};