'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactBemHelper = require('react-bem-helper');

var _reactBemHelper2 = _interopRequireDefault(_reactBemHelper);

var _shapes = require('./shapes');

var _VideoSearchResultBrightcove = require('./VideoSearchResultBrightcove');

var _VideoSearchResultBrightcove2 = _interopRequireDefault(_VideoSearchResultBrightcove);

var _VideoSearchResultYouTube = require('./VideoSearchResultYouTube');

var _VideoSearchResultYouTube2 = _interopRequireDefault(_VideoSearchResultYouTube);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) 2017-present, NDLA.
 *
 * This source code is licensed under the GPLv3 license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

var classes = new _reactBemHelper2.default({
  name: 'video-search',
  prefix: 'c-'
});

var VideoSearchList = function VideoSearchList(props) {
  var videos = props.videos,
      locale = props.locale,
      translations = props.translations,
      selectedType = props.selectedType,
      selectedVideo = props.selectedVideo,
      onSelectVideo = props.onSelectVideo,
      onVideoPreview = props.onVideoPreview,
      searching = props.searching;


  if ((!videos || videos.length === 0) && !searching) {
    return _react2.default.createElement(
      'p',
      null,
      translations.noResults
    );
  }
  if (searching && !(videos.length > 0)) {
    return _react2.default.createElement('div', classes('result-spinner'));
  }

  var videoresults = function videoresults() {
    if (selectedType === 'youtube') {
      return videos.map(function (video) {
        return _react2.default.createElement(_VideoSearchResultYouTube2.default, {
          key: video.pagemap.videoobject[0].videoid,
          video: video,
          onVideoPreview: onVideoPreview,
          selectedVideo: selectedVideo,
          onSelectVideo: onSelectVideo,
          translations: translations,
          locale: locale
        });
      });
    }

    return videos.map(function (video) {
      return _react2.default.createElement(_VideoSearchResultBrightcove2.default, {
        key: video.id,
        video: video,
        onVideoPreview: onVideoPreview,
        selectedVideo: selectedVideo,
        onSelectVideo: onSelectVideo,
        locale: locale,
        translations: translations
      });
    });
  };

  return _react2.default.createElement(
    'div',
    classes('list-inner'),
    videoresults()
  );
};

VideoSearchList.propTypes = {
  onSelectVideo: _propTypes2.default.func.isRequired,
  onVideoPreview: _propTypes2.default.func.isRequired,
  searching: _propTypes2.default.bool.isRequired,
  selectedType: _propTypes2.default.string.isRequired,
  selectedVideo: _propTypes2.default.oneOfType([_shapes.BrightcoveShape, _shapes.YouTubeShape]),
  videos: _propTypes2.default.oneOfType([_propTypes2.default.arrayOf(_shapes.BrightcoveShape), _propTypes2.default.arrayOf(_shapes.YouTubeShape)]),
  translations: _propTypes2.default.shape({
    searchPlaceholder: _propTypes2.default.string.isRequired,
    searchButtonTitle: _propTypes2.default.string.isRequired,
    loadMoreVideos: _propTypes2.default.string.isRequired
  }),
  locale: _propTypes2.default.string.isRequired
};

exports.default = VideoSearchList;